@@ -84,8 +84,6 @@ class ParaDateFiledServer(object):
         timeList = []
         differenceTime = 60 * 1000
         ToTime = self.getEndTime()
-        timeList.append(ToTime - 30 * differenceTime)
-        timeList.append(ToTime - 6 * 60 * differenceTime)
         timeList.append(ToTime - 12 * 60 * differenceTime)
         timeList.append(ToTime - 24 * 60 * differenceTime)
         startTime = random.choice(timeList)
