@@ -4,5 +4,7 @@ class date():
     def getName(self):
         name = str(random.choice(range(10, 999))) + '_' + str(random.choice(range(10, 999)))
         return name
-    def getDataType(self):
-        pass
\ No newline at end of file
+
+    def getNameWhipptree(self):
+        name = str(random.choice(range(10, 999))) + '-' + str(random.choice(range(10, 999)))
+        return name
\ No newline at end of file
